==> 3.2.0.tar.gz: test/method_call_handler/operation_type_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/operation_type_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    const MethodChannel channel = MethodChannel(
      CommonTestData.methodChannelName,
    );

    group("Given operationType is called from the native side", () {
      const methodName = 'operationType';
      late MockMethodChannelMethodCallCache mockCache;
      group("When the incoming parameters are correct", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test(
            "Then the oob platform operation is updated to the current operation type",
            () async {
          final mockOperation = MockOutOfBandPlatformOperation();
          final mockUpdatedOperation = MockOutOfBandPlatformOperation();
          const operationType = OutOfBandPlatformOperationType.registration;
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(mockOperation);
          when(mockOperation.updateOperationType(any))
              .thenReturn(mockUpdatedOperation);
          when(mockCache.updateOperation(
                  operationId: operationId, operation: mockUpdatedOperation))
              .thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OperationTypeTestData.correctArguments,
          );

          verifyInOrder([
            mockCache.getOperation(operationId),
            mockOperation.updateOperationType(operationType),
            mockCache.updateOperation(
                operationId: operationId, operation: mockUpdatedOperation)
          ]);
        });
      });

      group("When the incoming parameter are not correct", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then PlatformChannelException is thrown", () async {
          final mockOperation = MockOutOfBandPlatformOperation();
          final mockUpdatedOperation = MockOutOfBandPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(mockOperation);
          when(mockOperation.updateOperationType(any))
              .thenReturn(mockUpdatedOperation);
          when(mockCache.updateOperation(
                  operationId: operationId, operation: mockUpdatedOperation))
              .thenReturn(null);

          try {
            await channel.invokeMockMethod(
              methodName,
              OperationTypeTestData.wrongArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(e.code, "error");
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verifyNever(mockCache.getOperation(operationId));
        });
      });

      group("When the operationId is missing", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(mockCache.getOperation(operationId)).thenThrow(
              PlatformChannelException(
                  error: PlatformChannelError.noOperationFoundError(
                      operationId: operationId)));

          try {
            await channel.invokeMockMethod(
              methodName,
              OperationTypeTestData.wrongIdArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(mockCache.getOperation(operationId));
        });
      });
    });
  });
}

==> 3.4.0.tar.gz: test/method_call_handler/operation_type_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/operation_type_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    late MethodChannel channel;
    late MockMethodChannelMethodCallCache cache;
    const methodName = 'operationType';

    setUp(() {
      cache = MockMethodChannelMethodCallCache();
      NevisMobileAuthenticationSdkIos.mock(
          MethodChannelMethodCallHandler.mock(cache));
      channel = const MethodChannel(
        CommonTestData.methodChannelName,
      );
    });

    tearDown(() {
      channel.setMockMethodCallHandler(null);
      resetMockitoState();
    });

    group("Given $methodName is called from the native side", () {
      group("When the incoming parameters are correct", () {
        test(
            "Then the oob platform operation is updated to the current operation type",
            () async {
          final operation = MockOutOfBandPlatformOperation();
          final updatedOperation = MockOutOfBandPlatformOperation();
          const operationType = OutOfBandPlatformOperationType.registration;
          final operationId = CommonTestData.operationId;
          when(cache.getOperation(operationId)).thenReturn(operation);
          when(operation.updateOperationType(any)).thenReturn(updatedOperation);
          when(cache.updateOperation(
            operationId: operationId,
            operation: updatedOperation,
          )).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OperationTypeTestData.correctArguments,
          );

          verifyInOrder([
            cache.getOperation(operationId),
            operation.updateOperationType(operationType),
            cache.updateOperation(
              operationId: operationId,
              operation: updatedOperation,
            )
          ]);
        });
      });

      group("When the incoming parameter are not correct", () {
        test("Then PlatformChannelException is thrown", () async {
          try {
            await channel.invokeMockMethod(
              methodName,
              OperationTypeTestData.wrongArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(e.code, "error");
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verifyNever(cache.getOperation(any));
        });
      });

      group("When the operationId is missing", () {
        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(cache.getOperation(operationId)).thenThrow(
            PlatformChannelException(
              error: PlatformChannelError.noOperationFoundError(
                operationId: operationId,
              ),
            ),
          );

          try {
            await channel.invokeMockMethod(
              methodName,
              OperationTypeTestData.wrongIdArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(cache.getOperation(operationId));
        });
      });
    });
  });
}
